@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Hash::Util 'lock_keys';
 use List::Util 'first';
@@ -39,7 +39,6 @@ sub new {
 	    push @additional_mappings, $1;
 	} elsif ($arg =~ m{^debug(?:=(\d+))?$}) {
 	    $debug = defined $1 ? $1 : 1;
-	    require Data::Dumper; # we'll need it
 	} else {
 	    push @args_errors, $arg;
 	}
@@ -51,29 +50,32 @@ sub new {
     if (exists $ENV{CPAN_PLUGIN_SYSDEPS_DEBUG}) {
 	$debug = $ENV{CPAN_PLUGIN_SYSDEPS_DEBUG};
     }
+    if ($debug) {
+	require Data::Dumper; # we'll need it
+    }
 
     my $os                  = $options->{os} || $^O;
     my $linuxdistro         = '';
     my $linuxdistroversion  = 0;
     my $linuxdistrocodename = '';
     if ($os eq 'linux') {
-	# XXX fallback if lsb_release is unavailable?
+	my $linux_info = _detect_linux_distribution();
 	if (defined $options->{linuxdistro}) {
 	    $linuxdistro = $options->{linuxdistro};
 	} else {
-	    chomp($linuxdistro = lc `lsb_release -is`);
+	    $linuxdistro = lc $linux_info->{linuxdistro};
 	}
 
 	if (defined $options->{linuxdistroversion}) {
 	    $linuxdistroversion = $options->{linuxdistroversion};
 	} else {
-	    chomp($linuxdistroversion = `lsb_release -rs`); # XXX make it a version object? or make sure it's just X.Y?
+	    $linuxdistroversion = $linux_info->{linuxdistroversion}; # XXX make it a version object? or make sure it's just X.Y?
 	}
 
 	if (defined $options->{linuxdistrocodename}) {
 	    $linuxdistrocodename = $options->{linuxdistrocodename};
 	} else {
-	    chomp($linuxdistrocodename = `lsb_release -cs`);
+	    $linuxdistrocodename = $linux_info->{linuxdistrocodename};
 	}
     }
 
@@ -145,6 +147,58 @@ sub post_get {
 }
 
 # Helpers/Internal functions/methods
+sub _detect_linux_distribution {
+    if (-x '/usr/bin/lsb_release') {
+	_detect_linux_distribution_lsb_release();
+    } else {
+	_detect_linux_distribution_fallback();
+    }
+}
+
+sub _detect_linux_distribution_lsb_release {
+    my %info;
+    my @cmd = ('lsb_release', '-irc');
+    open my $fh, '-|', @cmd
+	or die "Error while running '@cmd': $!";
+    while(<$fh>) {
+	chomp;
+	if      (m{^Distributor ID:\s+(.*)}) {
+	    $info{linuxdistro} = $1;
+	} elsif (m{^Release:\s+(.*)}) {
+	    $info{linuxdistroversion} = $1;
+	} elsif (m{^Codename:\s+(.*)}) {
+	    $info{linuxdistrocodename} = $1;
+	} else {
+	    warn "WARNING: unexpected '@cmd' output '$_'";
+	}
+    }
+    close $fh
+	or die "Error while running '@cmd': $!";
+    \%info;
+}
+
+sub _detect_linux_distribution_fallback {
+    if (open my $fh, '<', '/etc/issue') {
+	chomp(my $line = <$fh>);
+	if      ($line =~ m{^Linux Mint (\d+) (\S+)}) {
+	    return {linuxdistro => 'LinuxMint', linuxdistroversion => $1, linuxdistrocodename => $2};
+	} elsif ($line =~ m{^(Debian) GNU/Linux (\d+)}) {
+	    my %info = (linuxdistro => $1, linuxdistroversion => $2);
+	    $info{linuxdistrocodename} =
+		{
+		 6 => 'squeeze',
+		 7 => 'wheezy',
+		 8 => 'jessie',
+		}->{$info{linuxdistroversion}};
+	    return \%info;
+	} else {
+	    warn "WARNING: don't know how to handle '$line'";
+	}
+    } else {
+	warn "WARNING: no /etc/issue available";
+    }
+}
+
 sub _is_linux_debian_like {
     my(undef, $linuxdistro) = @_;
     $linuxdistro =~ m{^(debian|ubuntu|linuxmint)$};
@@ -250,6 +304,8 @@ sub _map_cpandist {
 
 sub _find_missing_deb_packages {
     my($self, @packages) = @_;
+    return () if !@packages;
+
     # taken from ~/devel/deb-install.pl
     my %seen_packages;
     my @missing_packages;
@@ -266,9 +322,8 @@ sub _find_missing_deb_packages {
 	if (m{^(\S+) (.*)}) {
 	    if ($2 ne 'install ok installed') {
 		push @missing_packages, $1;
-	    } else {
-		$seen_packages{$1} = 1;
 	    }
+	    $seen_packages{$1} = 1;
 	} else {
 	    warn "ERROR: cannot parse $_, ignore line...\n";
 	}
@@ -339,6 +394,9 @@ sub _install_packages_commands {
 	}
     }
     push @install_cmd, 'install'; # XXX is this universal?
+    if ($self->{batch} && $self->{installer} eq 'pkg') {
+	push @install_cmd, '-y';
+    }
     push @install_cmd, @packages;
 
     ((@pre_cmd ? \@pre_cmd : ()), \@install_cmd);
@@ -495,6 +553,93 @@ specify alternatives in the form C<package1 | package2 | ...>.
 
 =back
 
+=head1 NOTES, LIMITATIONS, BUGS, TODO
+
+=over
+
+=item * Minimal requirements
+
+It is assumed that some dependencies are still installed: a C<make>, a
+suitable C compiler, maybe C<sudo>, C<patch> (e.g. if there are
+distroprefs using patch files) and of course C<perl>. On linux
+systems, C<lsb-release> is usually required (there's limited support
+for lsb-release-less operation on some Debian-like distributions).
+
+=item * Batch mode
+
+Make sure to configure the plugin with the C<batch> keyword (but read
+also L</Conflicting packages>). In F<CPAN/MyConfig.pm>:
+
+  'plugin_list' => [q[CPAN::Plugin::Sysdeps=batch]],
+
+Installation of system packages requires root priviliges. Therefore
+the installer is run using L<sudo(1)> if the executing user is not
+root. To avoid the need to enter a password either make sure that
+running the installer program (C<apt-get> or so) is made password-less
+in the F<sudoers> file, or run a wrapper like
+L<sudo_keeper|https://github.com/eserte/srezic-misc/blob/master/scripts/sudo_keeper>.
+
+=item * Error handling
+
+Failing things in the plugin are causing C<die()> calls. This can
+happen if packages cannot be installed (e.g. because of a bad network
+connection, the package not existing for the current os or
+distribution, package exists only in a "non-free" repository which
+needs to be added to F</etc/apt/sources.list>, another installer
+process having the exclusive lock...).
+
+=item * Conflicting packages
+
+System prerequisites specified in the mapping may conflict with
+already installed packages. Please note that with the "batch"
+configuration already installed conflicting packages are actually
+removed, at least on Debian systems.
+
+=item * Support for more OS and Linux distributions
+
+The default mapping has support for FreeBSD and Debian-like systems
+(but details are missing for distributions like Ubuntu or Mint).
+Support for other systems is missing.
+
+=item * Windows support
+
+Probably it is possible to support Windows by using installer tools
+like chocolatey.
+
+=back
+
+=head1 CREDITS
+
+This module was developed at the Perl QA Hackathon 2016
+L<http://act.qa-hackathon.org/qa2016/>
+which was made possible by the generosity of many sponsors:
+ 
+L<https://www.fastmail.com> FastMail,
+L<https://www.ziprecruiter.com> ZipRecruiter,
+L<http://www.activestate.com> ActiveState,
+L<http://www.opusvl.com> OpusVL,
+L<https://www.strato.com> Strato,
+L<http://www.surevoip.co.uk> SureVoIP,
+L<http://www.cv-library.co.uk> CV-Library,
+L<https://www.iinteractive.com/> Infinity,
+L<https://opensource.careers/perl-careers/> Perl Careers,
+L<https://www.mongodb.com> MongoDB,
+L<https://www.thinkproject.com> thinkproject!,
+L<https://www.dreamhost.com/> Dreamhost,
+L<http://www.perl6.org/> Perl 6,
+L<http://www.perl-services.de/> Perl Services,
+L<https://www.evozon.com/> Evozon,
+L<http://www.booking.com> Booking,
+L<http://eligo.co.uk> Eligo,
+L<http://www.oetiker.ch/> Oetiker+Partner,
+L<http://capside.com/en/> CAPSiDE,
+L<https://www.procura.nl/> Procura,
+L<https://constructor.io/> Constructor.io,
+L<https://metacpan.org/author/BABF> Robbie Bow,
+L<https://metacpan.org/author/RSAVAGE> Ron Savage,
+L<https://metacpan.org/author/ITCHARLIE> Charlie Gonzalez,
+L<https://twitter.com/jscook2345> Justin Cook.
+
 =head1 AUTHOR
 
 Slaven Rezic
