@@ -12,14 +12,17 @@ use constant like_debian => (linuxdistro => '~debian');
 sub mapping {
     (
      [cpanmod => 'AI::PBDD',
+      [os_freebsd,
+       # but does not work, kernel.h is also required
+       [package => 'bddsolve']],
       [like_debian,
        # but does not work, kernel.h is also required
        [package => 'libbdd-dev']]],
 
      [cpanmod => ['Algorithm::ConstructDFA::XS', 'Algorithm::LibLinear'],
+      # FreeBSD has c++ in the base system
       [like_debian,
        [package => 'g++']],
-      # XXX what about freebsd?
      ],
 
      [cpanmod => 'Alien::ffmpeg',
@@ -31,7 +34,7 @@ sub mapping {
 
      [cpanmod => 'Alien::FFTW3',
       [os_freebsd,
-       [package => 'fftw3']],
+       [package => ['fftw3', 'pkgconf']]],
       [like_debian,
        [package => 'libfftw3-dev', 'pkg-config | pkgconf']]],
 
@@ -55,6 +58,8 @@ sub mapping {
      ],
 
      [cpanmod => 'Alien::libtermkey',
+      [os_freebsd,
+       [package => ['libtool', 'gmake', 'pkgconf']]],
       [like_debian,
        [linuxdistrocodename => ['squeeze','wheezy'],
 	[package => ['libtool', 'libncurses5-dev']]],
@@ -71,26 +76,30 @@ sub mapping {
 
      [cpanmod => 'Alien::RRDtool',
       [os_freebsd,
-       [package => 'pkgconf']],
+       [package => ['pkgconf', 'glib', 'cairo', 'pango', 'libxml2']]],
       [like_debian,
        [package => 'pkg-config | pkgconf']]], # XXX pkg-config probably needed by much more CPAN distributions...
 
      [cpanmod => 'Alien::SVN',
       [os_freebsd,
-       [package => 'apr']],
+       # does not work, configure does not recognize sqlite
+       [package => ['apr', 'sqlite3']]],
       [like_debian,
        [package => ['libapr1-dev', 'libaprutil1-dev', 'libsqlite3-dev', 'zlib1g-dev']]]],
 
      [cpanmod => 'Alien::unibilium',
+      # XXX what about freebsd?
+      [os_freebsd,
+       [package => ['gmake', 'libtool', 'pkgconf']]],
       [like_debian,
        [linuxdistrocodename => ['squeeze','wheezy'],
 	[package => 'libtool']],
        [package => 'libtool-bin']],
-      # XXX what about freebsd?
      ],
 
      [cpanmod => 'Alien::Uninum', # probably!
       [os_freebsd,
+       # XXX does not work, configure does not accept -lgmp
        [package => 'gmp']],
       # XXX what about debian?
      ],
@@ -99,17 +108,19 @@ sub mapping {
       [package => 'unzip']],
 
      [cpanmod => 'Alien::wxWidgets',
-      [like_debian,
-       [package => 'libgtk2.0-dev']],
+      [os_freebsd,
       # XXX what about freebsd?
-     ],
+       [package => ['gtk2', 'pkgconf']]],
+      [like_debian,
+       [package => 'libgtk2.0-dev']]],
 
      [cpanmod => 'Archive::Rar',
       [os_freebsd,
        [package => 'rar'], # restricted, no binary package available, must build from ports
       ],
       [like_debian,
-       [package => 'rar']]],
+       [package => 'rar'], # available in jessie/non-free
+      ]],
 
      [cpanmod => 'Archive::SevenZip',
       [os_freebsd,
@@ -146,13 +157,15 @@ sub mapping {
        [package => 'libsamplerate0-dev']]],
 
      [cpanmod => 'Audio::PortAudio',
-      # XXX what about freebsd?
+      [os_freebsd,
+       [package => ['portaudio', 'pkgconf']]],
       [like_debian,
        # conflicts with libjack0
        [package => 'portaudio19-dev']]],
 
      [cpanmod => 'Audio::SndFile',
-      # XXX what about freebsd?
+      [os_freebsd,
+       [package => ['libsndfile', 'pkgconf']]],
       [like_debian,
        [package => 'libsndfile1-dev']]],
 
@@ -161,14 +174,15 @@ sub mapping {
        [package => 'taglib']],
       [like_debian,
        # but does not work, because the module wants taglib 1.9.1, but wheezy has 1.7.2-1
-       [package => 'libtag1-dev']]],
+       [package => ['libtag1-dev', 'g++']]]],
 
      [cpanmod => 'Authen::SASL::Cyrus',
-      # XXX what about freebsd?
+      [os_freebsd,
+       [package => 'cyrus-sasl']],
       [like_debian,
        [package => 'libsasl2-dev']]],
 
-     [cpanmod => 'BerkeleyDB',
+     [cpanmod => ['BerkeleyDB', 'BDB'],
       [os_freebsd,
        # FreeBSD has libdb in the base system, but this version is too old.
        # Make sure that a corresponding distroprefs file matches this library.
@@ -185,18 +199,19 @@ sub mapping {
        # htslib exists, but does not seem to be compatible with the perl module
        [package => 'htslib']],
       [like_debian,
+       # also does not work...
        [package => 'libhts-dev']]],
 
      [cpanmod => 'Bio::Phylo::Beagle',
       # XXX what about freebsd?
       [like_debian,
-       [package => 'libhmsbeagle-dev']]],
+       [package => ['libhmsbeagle-dev', 'pkg-config | pkgconf']]]],
 
      [cpanmod => 'Bio::SCF',
       [os_freebsd,
        [package => 'io_lib']],
       [like_debian,
-       [package => 'libstaden-read-dev']]],
+       [package => ['libstaden-read-dev', 'zlib1g-dev']]]],
 
      [cpanmod => 'Cache::Memcached::XS',
       [os_freebsd,
@@ -229,7 +244,7 @@ sub mapping {
      [cpanmod => 'Chipcard::PCSC',
       # XXX what about freebsd?
       [like_debian,
-       [package => 'libpcsclite-dev']]],
+       [package => ['bzip2', 'libpcsclite-dev', 'pkg-config | pkgconf']]]], # bzip2 needed for extraction
 
      [cpanmod => ['ClamAV::Client', 'File::Scan::ClamAV'],
       [os_freebsd,
@@ -239,22 +254,24 @@ sub mapping {
 
      [cpanmod => ['Compress::LZMA::Simple', 'Compress::Raw::Lzma'],
       [os_freebsd,
+       # this one does not work with Compress::Raw::Lzma under freebsd
        [package => 'lzmalib']],
       [like_debian,
-       # probably this one does not work with Compress::LZMA::Simple under debian
+       # this one does not work with Compress::LZMA::Simple under debian
        [package => 'liblzma-dev']]],
 
      [cpanmod => 'Compress::LZO',
-      # XXX what about freebsd?
+      [os_freebsd,
+       [package => 'lzo2']],
       [like_debian,
        [package => 'liblzo2-dev']]],
 
      [cpanmod => 'Config::Augeas',
       [os_freebsd,
-       [package => 'augeas']],
+       [package => ['augeas', 'pkgconf']]],
       [like_debian,
        # but the wheezy version is too old, module wants 1.0.0, wheezy has 0.10.0
-       [package => 'libaugeas-dev']]],
+       [package => ['libaugeas-dev', 'pkg-config | pkgconf']]]],
 
      [cpanmod => 'Crypt::Cracklib',
       [os_freebsd,
@@ -270,6 +287,14 @@ sub mapping {
 	[package => 'libgmp3-dev']],
        [package => 'libgmp-dev']]],
 
+     [cpanmod => 'Crypt::GCrypt',
+      [os_freebsd,
+       # Does not work, see the patches in the p5-Crypt-GCrypt port
+       [package => 'libgcrypt']],
+      [like_debian,
+       # Neither libgcrypt11 nor libgcrypt20 seem to work.
+       [package => 'libgcrypt11-dev']]],
+
      [cpanmod => 'Crypt::MCrypt',
       [os_freebsd,
        [package => 'libmcrypt']],
@@ -303,19 +328,19 @@ sub mapping {
 
      [cpanmod => 'CSS::Croco',
       [os_freebsd,
-       [package => 'libcroco']],
+       [package => ['libcroco', 'pkgconf']]],
       [like_debian,
        [package => 'libcroco3-dev']]],
 
      [cpanmod => 'Curses::UI::Mousehandler::GPM',
       [like_debian,
-       [package => 'libgpm-dev', 'libncursesw5-dev']]],
+       [package => ['libgpm-dev', 'libncurses5-dev']]]],
 
      [cpanmod => 'Database::Cassandra::Client',
       [os_freebsd,
        # but does not work, and neither does cassandra2
        [package => 'cassandra']],
-      # XXX what about debian?
+      # cassandra package not available on debian
      ],
 
      [cpanmod => ['Data::UUID::LibUUID', 'UUID'],
@@ -367,14 +392,14 @@ sub mapping {
      [cpanmod => 'DBD::Pg',
       [os_freebsd,
        [package => 'postgresql93-server']],
-      # XXX what about debian?
-     ],
+      [like_debian,
+       [package => 'libpq-dev']]],
 
      [cpanmod => 'Deliantra::Client',
       [os_freebsd,
        [package => ['sdl2', 'sdl2_image', 'sdl2_mixer']]],
       [like_debian,
-       [package => ['libsdl1.2-dev', 'libsdl-image1.2-dev', 'libsdl-mixer1.2-dev']]]],
+       [package => ['libsdl1.2-dev', 'libsdl-image1.2-dev', 'libsdl-mixer1.2-dev', 'libglib2.0-dev']]]],
 
      [cpanmod => 'Device::Cdio',
       [like_debian,
@@ -388,7 +413,7 @@ sub mapping {
      ],
 
      [cpanmod => 'DLM::Client',
-      # XXX what about freebsd?
+      # libdlm does not seem to exist on FreeBSD
       [like_debian,
        [package => 'libdlm-dev']]],
      
@@ -424,6 +449,17 @@ sub mapping {
       [like_debian,
        [package => 'libevent-dev']]],
 
+     [cpanmod => 'ExtUtils::CppGuess',
+      # FreeBSD has c++ in the base system
+      [like_debian,
+       [package => 'g++']]],
+
+     [cpanmod => 'ExtUtils::PkgConfig',
+      [os_freebsd,
+       [package => 'pkgconf']],
+      [like_debian,
+       [package => 'pkg-config | pkgconf']]],
+
      [cpanmod => 'File::LibMagic',
       # XXX what about freebsd?
       [like_debian,
@@ -445,12 +481,12 @@ sub mapping {
       [package => 'gocr']],
 
      [cpanmod => 'FTDI::D2XX',
-      # XXX what about freebsd?
+      # neither libftdi nor libftdi1 seem to work on FreeBSD
       [like_debian,
        [package => 'libftdi-dev']]],
 
      [cpanmod => 'Fuse',
-      # XXX what about freebsd?
+      # Fuse.pm does not work on freebsd
       [like_debian,
        [package => 'libfuse-dev']]],
 
@@ -458,11 +494,13 @@ sub mapping {
       [os_freebsd,
        [package => 'gd']],
       [like_debian,
+       [linuxdistrocodename => ['precise'],
+	[package => 'libgd-noxpm-dev | libgd2-xpm-dev']],
        [package => 'libgd-dev']]],
 
      [cpanmod => 'Gearman::XS',
       [os_freebsd,
-       [package => 'gearmand'], # not for small disks, needs boost-libs
+       [package => 'gearmand-devel'], # untested; not for small disks, needs boost-libs
       ],
       [like_debian,
        [package => 'libgearman-dev']]],
@@ -946,7 +984,7 @@ sub mapping {
      ],
 
      [cpanmod => 'Net::LibAsyncNS',
-      # XXX what about freebsd?
+      # it seems there's no libasyncns for freebsd
       [like_debian,
        [package => 'libasyncns-dev']]],
 
@@ -1011,6 +1049,11 @@ sub mapping {
 	[package => []]], # not available
        [package => ['libzookeeper-mt-dev', 'zookeeperd']]]],
 
+     [cpanmod => 'NewRelic::Agent',
+      # freebsd does not work, bundled .so files are linux-only
+      [like_debian,
+       [package => ['g++', 'libcurl3']]]],
+
      [cpanmod => 'Ogg::Vorbis::Decoder',
       [os_freebsd,
        [package => 'libvorbis']],
@@ -1035,8 +1078,8 @@ sub mapping {
      [cpanmod => 'Pango',
       [os_freebsd,
        [package => 'pango']],
-      # XXX what about debian?
-     ],
+      [like_debian,
+       [package => 'libpango1.0-dev']]],
 
      [cpanmod => 'Parallel::Pvm',
       [os_freebsd,
@@ -1046,9 +1089,9 @@ sub mapping {
 
      [cpanmod => 'Passwd::Keyring::Gnome',
       [os_freebsd,
-       [package => 'gnome-keyring']],
-      # XXX what about debian?
-     ],
+       [package => ['libgnome-keyring', 'pkgconf']]],
+      [like_debian,
+       [package => 'libgnome-keyring-dev']]],
 
      [cpanmod => 'PerlQt',
       [like_debian,
@@ -1071,8 +1114,10 @@ sub mapping {
       [like_debian,
        [package => ['libpoppler-dev', 'libpoppler-glib-dev']]]],
 
-#	# for Prima...
-#	package { "libX11": ensure => installed }
+     [cpanmod => 'Prima',
+      # XXX what about freebsd?
+      [like_debian,
+       [package => [qw(libx11-dev libxpm-dev libgif-dev libpng12-dev libjpeg-dev), 'pkg-config | pkgconf']]]], # XXX maybe also add libtiff...
 
      [cpanmod => 'PulseAudio',
       [package => 'pulseaudio']],
@@ -1337,7 +1382,7 @@ sub mapping {
 
      [cpanmod => 'XML::Parser',
       [os_freebsd,
-       [package => 'expat2']],
+       [package => 'expat']],
       [like_debian,
        [package => 'libexpat1-dev']]],
 
